@@ -25,7 +25,6 @@ import java.io.FileFilter;
 import java.util.Stack;
 
 import org.videolan.vlc.Media;
-import org.videolan.vlc.MediaLibrary;
 import org.videolan.vlc.R;
 import org.videolan.vlc.Util;
 
@@ -61,8 +60,8 @@ public class BrowserActivity extends ListActivity {
 
     @Override
     protected void onCreate(Bundle savedInstanceState) {
-        setContentView(R.layout.browser);
         super.onCreate(savedInstanceState);
+        setContentView(R.layout.browser);
         mAdapter = new BrowserAdapter(this);
         setListAdapter(mAdapter);
 
@@ -81,9 +80,9 @@ public class BrowserActivity extends ListActivity {
 
     @Override
     protected void onDestroy() {
+        super.onDestroy();
         mAdapter.clear();
         mScollStates.clear();
-        super.onDestroy();
     }
 
     private void openDir(File file) {
@@ -135,13 +134,6 @@ public class BrowserActivity extends ListActivity {
         return super.onKeyDown(keyCode, event);
     }
 
-    @Override
-    protected void onStop() {
-        // Update the MediaList
-        MediaLibrary.getInstance(this).loadMediaItems(this);
-        super.onStop();
-    }
-
     /**
      * Filter: accept only directories
      */
