@@ -29,6 +29,7 @@ import java.math.BigInteger;
 import java.security.MessageDigest;
 import java.security.NoSuchAlgorithmException;
 
+import org.videolan.vlc.BitmapCache;
 import org.videolan.vlc.Media;
 import org.videolan.vlc.MurmurHash;
 import org.videolan.vlc.R;
@@ -46,6 +47,7 @@ import android.graphics.Bitmap.CompressFormat;
 import android.graphics.BitmapFactory;
 import android.media.RingtoneManager;
 import android.net.Uri;
+import android.os.Environment;
 import android.provider.MediaStore;
 import android.util.Log;
 
@@ -53,9 +55,8 @@ public class AudioUtil {
 
     public final static String TAG = "VLC/AudioUtil";
 
-    @SuppressLint("SdCardPath")
-    public final static String CACHE_DIR = "/sdcard/Android/data/org.videolan.vlc/cache";
-    public final static String COVER_DIR = CACHE_DIR + "/covers/";
+    public static String CACHE_DIR = null;
+    public static String COVER_DIR = null;
 
     public static void setRingtone( Media song, Activity activity){
         File newringtone = Util.URItoFile(song.getLocation());
@@ -78,13 +79,20 @@ public class AudioUtil {
                 );
     }
 
-    public static void prepareCacheFolder() {
+    @SuppressLint("NewApi")
+    public static void prepareCacheFolder(Context context) {
+        if (Util.isFroyoOrLater() && Util.hasExternalStorage())
+            CACHE_DIR = context.getExternalCacheDir().getPath();
+        else
+            CACHE_DIR = Environment.getExternalStorageDirectory().getPath() + "/Android/data/" + context.getPackageName() + "/cache";
+        COVER_DIR = CACHE_DIR + "/covers/";
+
         File file = new File(COVER_DIR);
         if (!file.exists())
             file.mkdirs();
     }
 
-    private static Bitmap getCoverFromMediaStore(Context context, Media media) {
+    private static String getCoverFromMediaStore(Context context, Media media) {
         ContentResolver contentResolver = context.getContentResolver();
         Uri uri = android.provider.MediaStore.Audio.Albums.EXTERNAL_CONTENT_URI;
         Cursor cursor = contentResolver.query(uri, new String[] {
@@ -101,19 +109,15 @@ public class AudioUtil {
             int titleColumn = cursor.getColumnIndex(android.provider.MediaStore.Audio.Albums.ALBUM_ART);
             String albumArt = cursor.getString(titleColumn);
             cursor.close();
-            if(albumArt != null) { // could be null (no album art stored)
-                Bitmap b = BitmapFactory.decodeFile(albumArt);
-                if (b != null)
-                    return b;
-            }
+            return albumArt;
         }
         return null;
     }
 
-    private static Bitmap getCoverFromVlc(Context context, Media media) throws NoSuchAlgorithmException, UnsupportedEncodingException {
+    private static String getCoverFromVlc(Context context, Media media) throws NoSuchAlgorithmException, UnsupportedEncodingException {
         String artworkURL = media.getArtworkURL();
         if (artworkURL != null && artworkURL.startsWith("file://")) {
-            return BitmapFactory.decodeFile(Uri.decode(artworkURL).replace("file://", ""));
+            return Uri.decode(artworkURL).replace("file://", "");
         } else if(artworkURL != null && artworkURL.startsWith("attachment://")) {
             // Decode if the album art is embedded in the file
             String mArtist = media.getArtist();
@@ -140,51 +144,68 @@ public class AudioUtil {
                 artworkURL = CACHE_DIR + "/art/artistalbum/" + mArtist + "/" + mAlbum + "/art.png";
             }
 
-            return BitmapFactory.decodeFile(artworkURL);
+            return artworkURL;
         }
         return null;
     }
 
-    private static Bitmap getCoverFromFolder(Context context, Media media) {
+    private static String getCoverFromFolder(Context context, Media media) {
         File f = Util.URItoFile(media.getLocation());
         for (File s : f.getParentFile().listFiles()) {
             if (s.getAbsolutePath().endsWith("png") ||
                     s.getAbsolutePath().endsWith("jpg"))
-                return BitmapFactory.decodeFile(s.getAbsolutePath());
+                return s.getAbsolutePath();
         }
         return null;
     }
 
+    @SuppressLint("NewApi")
     public synchronized static Bitmap getCover(Context context, Media media, int width) {
+        String coverPath = null;
         Bitmap cover = null;
         String cachePath = null;
 
+        // if external storage is not available, skip covers to prevent slow audio browsing
+        if (!Util.hasExternalStorage() && width > 0)
+            return null;
+
         try {
             // try to load from cache
             int hash = MurmurHash.hash32(media.getArtist()+media.getAlbum());
             cachePath = COVER_DIR + (hash >= 0 ? "" + hash : "m" + (-hash)) + "_" + width;
-            cover = readBitmap(cachePath);
+
+            BitmapCache cache = BitmapCache.getInstance();
+            // try to get the cover from the LRUCache first
+            cover = cache.getBitmapFromMemCache(cachePath);
             if (cover != null)
                 return cover;
 
-            // try to get the cover from vlc art cache
-            cover = getCoverFromVlc(context, media);
+            // try to get the cover from the storage cache
+            File cacheFile = new File(cachePath);
+            if (cacheFile != null && cacheFile.exists()) {
+                if (cacheFile.length() > 0)
+                    coverPath = cachePath;
+                else
+                    return null;
+            }
+
+            if (coverPath == null)
+                coverPath = getCoverFromVlc(context, media);
 
             // no found yet, looking in folder
-            if (cover == null)
-                cover = getCoverFromFolder(context, media);
+            if (coverPath == null)
+                coverPath = getCoverFromFolder(context, media);
 
             // try to get the cover from android MediaStore
-            if (cover == null)
-                cover = getCoverFromMediaStore(context, media);
+            if (coverPath == null)
+                coverPath = getCoverFromMediaStore(context, media);
 
-            // scale down if requested
-            if (cover != null && width > 0)
-                cover = Util.scaleDownBitmap(context, cover, width);
+            // read (and scale?) the bitmap
+            cover = readCoverBitmap(context, coverPath, width);
 
-            // store cover into cache
-            if (cover != null)
-                writeBitmap(cover, cachePath);
+            // store cover into both cache
+            writeBitmap(cover, cachePath);
+            cache.addBitmapToMemCache(cachePath, cover);
 
         } catch (Exception e) {
             e.printStackTrace();
@@ -197,7 +218,8 @@ public class AudioUtil {
         try {
             File file = new File(path);
             out = new BufferedOutputStream(new FileOutputStream(file), 4096);
-            bitmap.compress(CompressFormat.JPEG, 90, out);
+            if (bitmap != null)
+                bitmap.compress(CompressFormat.JPEG, 90, out);
         } catch (Exception e) {
             Log.e(TAG, "writeBitmap failed : "+ e.getMessage());
         } finally {
@@ -207,9 +229,13 @@ public class AudioUtil {
         }
     }
 
-    private static Bitmap readBitmap(String path) {
-        File file = new File(path);
-        if (file == null || !file.exists()) return null;
-        return BitmapFactory.decodeFile(path);
+    private static Bitmap readCoverBitmap(Context context, String path, int width) {
+        Bitmap cover = BitmapFactory.decodeFile(path);
+
+        // scale down if requested
+        if (cover != null && width > 0)
+            cover = Util.scaleDownBitmap(context, cover, width);
+
+        return cover;
     }
 }
