@@ -32,12 +32,12 @@ import org.videolan.vlc.Util;
 import org.videolan.vlc.WeakHandler;
 
 import android.app.ListActivity;
-import android.content.Intent;
 import android.graphics.Bitmap;
 import android.graphics.Bitmap.Config;
 import android.os.Bundle;
 import android.os.Handler;
 import android.os.Message;
+import android.util.DisplayMetrics;
 import android.view.View;
 import android.widget.ImageButton;
 import android.widget.ImageView;
@@ -94,9 +94,7 @@ public class MediaInfoActivity extends ListActivity {
     }
 
     public void onPlayClick(View v) {
-        Intent intent = new Intent(this, VideoPlayerActivity.class);
-        intent.putExtra("itemLocation", mItem.getLocation());
-        startActivity(intent);
+        VideoPlayerActivity.start(this, mItem.getLocation());
     }
 
     Runnable mLoadImage = new Runnable() {
@@ -113,8 +111,9 @@ public class MediaInfoActivity extends ListActivity {
             mHandler.sendEmptyMessage(NEW_TEXT);
 
             if (mImage == null) {
-                int width = Math.min(getWindowManager().getDefaultDisplay().getWidth(),
-                                     getWindowManager().getDefaultDisplay().getHeight());
+                DisplayMetrics screen = new DisplayMetrics();
+                getWindowManager().getDefaultDisplay().getMetrics(screen);
+                int width = Math.min(screen.widthPixels, screen.heightPixels);
                 int height = width * 9 / 16;
 
                 // Get the thumbnail.
@@ -156,6 +155,8 @@ public class MediaInfoActivity extends ListActivity {
         @Override
         public void handleMessage(Message msg) {
             MediaInfoActivity activity = getOwner();
+            if(activity == null) return;
+
             switch (msg.what) {
                 case NEW_IMAGE:
                     activity.updateImage();
